# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RegisteredDomainArgs', 'RegisteredDomain']

@pulumi.input_type
class RegisteredDomainArgs:
    def __init__(__self__, *,
                 domain_name: pulumi.Input[str],
                 admin_contact: Optional[pulumi.Input['RegisteredDomainAdminContactArgs']] = None,
                 admin_privacy: Optional[pulumi.Input[bool]] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]]] = None,
                 registrant_contact: Optional[pulumi.Input['RegisteredDomainRegistrantContactArgs']] = None,
                 registrant_privacy: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tech_contact: Optional[pulumi.Input['RegisteredDomainTechContactArgs']] = None,
                 tech_privacy: Optional[pulumi.Input[bool]] = None,
                 transfer_lock: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a RegisteredDomain resource.
        :param pulumi.Input[str] domain_name: The name of the registered domain.
        :param pulumi.Input['RegisteredDomainAdminContactArgs'] admin_contact: Details about the domain administrative contact.
        :param pulumi.Input[bool] admin_privacy: Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] auto_renew: Whether the domain registration is set to renew automatically. Default: `true`.
        :param pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]] name_servers: The list of nameservers for the domain.
        :param pulumi.Input['RegisteredDomainRegistrantContactArgs'] registrant_contact: Details about the domain registrant.
        :param pulumi.Input[bool] registrant_privacy: Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input['RegisteredDomainTechContactArgs'] tech_contact: Details about the domain technical contact.
        :param pulumi.Input[bool] tech_privacy: Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] transfer_lock: Whether the domain is locked for transfer. Default: `true`.
        """
        pulumi.set(__self__, "domain_name", domain_name)
        if admin_contact is not None:
            pulumi.set(__self__, "admin_contact", admin_contact)
        if admin_privacy is not None:
            pulumi.set(__self__, "admin_privacy", admin_privacy)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)
        if registrant_contact is not None:
            pulumi.set(__self__, "registrant_contact", registrant_contact)
        if registrant_privacy is not None:
            pulumi.set(__self__, "registrant_privacy", registrant_privacy)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tech_contact is not None:
            pulumi.set(__self__, "tech_contact", tech_contact)
        if tech_privacy is not None:
            pulumi.set(__self__, "tech_privacy", tech_privacy)
        if transfer_lock is not None:
            pulumi.set(__self__, "transfer_lock", transfer_lock)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Input[str]:
        """
        The name of the registered domain.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="adminContact")
    def admin_contact(self) -> Optional[pulumi.Input['RegisteredDomainAdminContactArgs']]:
        """
        Details about the domain administrative contact.
        """
        return pulumi.get(self, "admin_contact")

    @admin_contact.setter
    def admin_contact(self, value: Optional[pulumi.Input['RegisteredDomainAdminContactArgs']]):
        pulumi.set(self, "admin_contact", value)

    @property
    @pulumi.getter(name="adminPrivacy")
    def admin_privacy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "admin_privacy")

    @admin_privacy.setter
    def admin_privacy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "admin_privacy", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the domain registration is set to renew automatically. Default: `true`.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]]]:
        """
        The list of nameservers for the domain.
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]]]):
        pulumi.set(self, "name_servers", value)

    @property
    @pulumi.getter(name="registrantContact")
    def registrant_contact(self) -> Optional[pulumi.Input['RegisteredDomainRegistrantContactArgs']]:
        """
        Details about the domain registrant.
        """
        return pulumi.get(self, "registrant_contact")

    @registrant_contact.setter
    def registrant_contact(self, value: Optional[pulumi.Input['RegisteredDomainRegistrantContactArgs']]):
        pulumi.set(self, "registrant_contact", value)

    @property
    @pulumi.getter(name="registrantPrivacy")
    def registrant_privacy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "registrant_privacy")

    @registrant_privacy.setter
    def registrant_privacy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "registrant_privacy", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="techContact")
    def tech_contact(self) -> Optional[pulumi.Input['RegisteredDomainTechContactArgs']]:
        """
        Details about the domain technical contact.
        """
        return pulumi.get(self, "tech_contact")

    @tech_contact.setter
    def tech_contact(self, value: Optional[pulumi.Input['RegisteredDomainTechContactArgs']]):
        pulumi.set(self, "tech_contact", value)

    @property
    @pulumi.getter(name="techPrivacy")
    def tech_privacy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "tech_privacy")

    @tech_privacy.setter
    def tech_privacy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tech_privacy", value)

    @property
    @pulumi.getter(name="transferLock")
    def transfer_lock(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the domain is locked for transfer. Default: `true`.
        """
        return pulumi.get(self, "transfer_lock")

    @transfer_lock.setter
    def transfer_lock(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "transfer_lock", value)


@pulumi.input_type
class _RegisteredDomainState:
    def __init__(__self__, *,
                 abuse_contact_email: Optional[pulumi.Input[str]] = None,
                 abuse_contact_phone: Optional[pulumi.Input[str]] = None,
                 admin_contact: Optional[pulumi.Input['RegisteredDomainAdminContactArgs']] = None,
                 admin_privacy: Optional[pulumi.Input[bool]] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 creation_date: Optional[pulumi.Input[str]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 expiration_date: Optional[pulumi.Input[str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]]] = None,
                 registrant_contact: Optional[pulumi.Input['RegisteredDomainRegistrantContactArgs']] = None,
                 registrant_privacy: Optional[pulumi.Input[bool]] = None,
                 registrar_name: Optional[pulumi.Input[str]] = None,
                 registrar_url: Optional[pulumi.Input[str]] = None,
                 reseller: Optional[pulumi.Input[str]] = None,
                 status_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tech_contact: Optional[pulumi.Input['RegisteredDomainTechContactArgs']] = None,
                 tech_privacy: Optional[pulumi.Input[bool]] = None,
                 transfer_lock: Optional[pulumi.Input[bool]] = None,
                 updated_date: Optional[pulumi.Input[str]] = None,
                 whois_server: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RegisteredDomain resources.
        :param pulumi.Input[str] abuse_contact_email: Email address to contact to report incorrect contact information for a domain, to report that the domain is being used to send spam, to report that someone is cybersquatting on a domain name, or report some other type of abuse.
        :param pulumi.Input[str] abuse_contact_phone: Phone number for reporting abuse.
        :param pulumi.Input['RegisteredDomainAdminContactArgs'] admin_contact: Details about the domain administrative contact.
        :param pulumi.Input[bool] admin_privacy: Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] auto_renew: Whether the domain registration is set to renew automatically. Default: `true`.
        :param pulumi.Input[str] creation_date: The date when the domain was created as found in the response to a WHOIS query.
        :param pulumi.Input[str] domain_name: The name of the registered domain.
        :param pulumi.Input[str] expiration_date: The date when the registration for the domain is set to expire.
        :param pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]] name_servers: The list of nameservers for the domain.
        :param pulumi.Input['RegisteredDomainRegistrantContactArgs'] registrant_contact: Details about the domain registrant.
        :param pulumi.Input[bool] registrant_privacy: Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[str] registrar_name: Name of the registrar of the domain as identified in the registry.
        :param pulumi.Input[str] registrar_url: Web address of the registrar.
        :param pulumi.Input[str] reseller: Reseller of the domain.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] status_lists: List of [domain name status codes](https://www.icann.org/resources/pages/epp-status-codes-2014-06-16-en).
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        :param pulumi.Input['RegisteredDomainTechContactArgs'] tech_contact: Details about the domain technical contact.
        :param pulumi.Input[bool] tech_privacy: Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] transfer_lock: Whether the domain is locked for transfer. Default: `true`.
        :param pulumi.Input[str] updated_date: The last updated date of the domain as found in the response to a WHOIS query.
        :param pulumi.Input[str] whois_server: The fully qualified name of the WHOIS server that can answer the WHOIS query for the domain.
        """
        if abuse_contact_email is not None:
            pulumi.set(__self__, "abuse_contact_email", abuse_contact_email)
        if abuse_contact_phone is not None:
            pulumi.set(__self__, "abuse_contact_phone", abuse_contact_phone)
        if admin_contact is not None:
            pulumi.set(__self__, "admin_contact", admin_contact)
        if admin_privacy is not None:
            pulumi.set(__self__, "admin_privacy", admin_privacy)
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if creation_date is not None:
            pulumi.set(__self__, "creation_date", creation_date)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)
        if registrant_contact is not None:
            pulumi.set(__self__, "registrant_contact", registrant_contact)
        if registrant_privacy is not None:
            pulumi.set(__self__, "registrant_privacy", registrant_privacy)
        if registrar_name is not None:
            pulumi.set(__self__, "registrar_name", registrar_name)
        if registrar_url is not None:
            pulumi.set(__self__, "registrar_url", registrar_url)
        if reseller is not None:
            pulumi.set(__self__, "reseller", reseller)
        if status_lists is not None:
            pulumi.set(__self__, "status_lists", status_lists)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_all is not None:
            pulumi.set(__self__, "tags_all", tags_all)
        if tech_contact is not None:
            pulumi.set(__self__, "tech_contact", tech_contact)
        if tech_privacy is not None:
            pulumi.set(__self__, "tech_privacy", tech_privacy)
        if transfer_lock is not None:
            pulumi.set(__self__, "transfer_lock", transfer_lock)
        if updated_date is not None:
            pulumi.set(__self__, "updated_date", updated_date)
        if whois_server is not None:
            pulumi.set(__self__, "whois_server", whois_server)

    @property
    @pulumi.getter(name="abuseContactEmail")
    def abuse_contact_email(self) -> Optional[pulumi.Input[str]]:
        """
        Email address to contact to report incorrect contact information for a domain, to report that the domain is being used to send spam, to report that someone is cybersquatting on a domain name, or report some other type of abuse.
        """
        return pulumi.get(self, "abuse_contact_email")

    @abuse_contact_email.setter
    def abuse_contact_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "abuse_contact_email", value)

    @property
    @pulumi.getter(name="abuseContactPhone")
    def abuse_contact_phone(self) -> Optional[pulumi.Input[str]]:
        """
        Phone number for reporting abuse.
        """
        return pulumi.get(self, "abuse_contact_phone")

    @abuse_contact_phone.setter
    def abuse_contact_phone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "abuse_contact_phone", value)

    @property
    @pulumi.getter(name="adminContact")
    def admin_contact(self) -> Optional[pulumi.Input['RegisteredDomainAdminContactArgs']]:
        """
        Details about the domain administrative contact.
        """
        return pulumi.get(self, "admin_contact")

    @admin_contact.setter
    def admin_contact(self, value: Optional[pulumi.Input['RegisteredDomainAdminContactArgs']]):
        pulumi.set(self, "admin_contact", value)

    @property
    @pulumi.getter(name="adminPrivacy")
    def admin_privacy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "admin_privacy")

    @admin_privacy.setter
    def admin_privacy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "admin_privacy", value)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the domain registration is set to renew automatically. Default: `true`.
        """
        return pulumi.get(self, "auto_renew")

    @auto_renew.setter
    def auto_renew(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_renew", value)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> Optional[pulumi.Input[str]]:
        """
        The date when the domain was created as found in the response to a WHOIS query.
        """
        return pulumi.get(self, "creation_date")

    @creation_date.setter
    def creation_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "creation_date", value)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the registered domain.
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[str]]:
        """
        The date when the registration for the domain is set to expire.
        """
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expiration_date", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]]]:
        """
        The list of nameservers for the domain.
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RegisteredDomainNameServerArgs']]]]):
        pulumi.set(self, "name_servers", value)

    @property
    @pulumi.getter(name="registrantContact")
    def registrant_contact(self) -> Optional[pulumi.Input['RegisteredDomainRegistrantContactArgs']]:
        """
        Details about the domain registrant.
        """
        return pulumi.get(self, "registrant_contact")

    @registrant_contact.setter
    def registrant_contact(self, value: Optional[pulumi.Input['RegisteredDomainRegistrantContactArgs']]):
        pulumi.set(self, "registrant_contact", value)

    @property
    @pulumi.getter(name="registrantPrivacy")
    def registrant_privacy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "registrant_privacy")

    @registrant_privacy.setter
    def registrant_privacy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "registrant_privacy", value)

    @property
    @pulumi.getter(name="registrarName")
    def registrar_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the registrar of the domain as identified in the registry.
        """
        return pulumi.get(self, "registrar_name")

    @registrar_name.setter
    def registrar_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "registrar_name", value)

    @property
    @pulumi.getter(name="registrarUrl")
    def registrar_url(self) -> Optional[pulumi.Input[str]]:
        """
        Web address of the registrar.
        """
        return pulumi.get(self, "registrar_url")

    @registrar_url.setter
    def registrar_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "registrar_url", value)

    @property
    @pulumi.getter
    def reseller(self) -> Optional[pulumi.Input[str]]:
        """
        Reseller of the domain.
        """
        return pulumi.get(self, "reseller")

    @reseller.setter
    def reseller(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "reseller", value)

    @property
    @pulumi.getter(name="statusLists")
    def status_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of [domain name status codes](https://www.icann.org/resources/pages/epp-status-codes-2014-06-16-en).
        """
        return pulumi.get(self, "status_lists")

    @status_lists.setter
    def status_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "status_lists", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")

    @tags_all.setter
    def tags_all(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags_all", value)

    @property
    @pulumi.getter(name="techContact")
    def tech_contact(self) -> Optional[pulumi.Input['RegisteredDomainTechContactArgs']]:
        """
        Details about the domain technical contact.
        """
        return pulumi.get(self, "tech_contact")

    @tech_contact.setter
    def tech_contact(self, value: Optional[pulumi.Input['RegisteredDomainTechContactArgs']]):
        pulumi.set(self, "tech_contact", value)

    @property
    @pulumi.getter(name="techPrivacy")
    def tech_privacy(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "tech_privacy")

    @tech_privacy.setter
    def tech_privacy(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "tech_privacy", value)

    @property
    @pulumi.getter(name="transferLock")
    def transfer_lock(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the domain is locked for transfer. Default: `true`.
        """
        return pulumi.get(self, "transfer_lock")

    @transfer_lock.setter
    def transfer_lock(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "transfer_lock", value)

    @property
    @pulumi.getter(name="updatedDate")
    def updated_date(self) -> Optional[pulumi.Input[str]]:
        """
        The last updated date of the domain as found in the response to a WHOIS query.
        """
        return pulumi.get(self, "updated_date")

    @updated_date.setter
    def updated_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_date", value)

    @property
    @pulumi.getter(name="whoisServer")
    def whois_server(self) -> Optional[pulumi.Input[str]]:
        """
        The fully qualified name of the WHOIS server that can answer the WHOIS query for the domain.
        """
        return pulumi.get(self, "whois_server")

    @whois_server.setter
    def whois_server(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "whois_server", value)


class RegisteredDomain(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainAdminContactArgs']]] = None,
                 admin_privacy: Optional[pulumi.Input[bool]] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RegisteredDomainNameServerArgs']]]]] = None,
                 registrant_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainRegistrantContactArgs']]] = None,
                 registrant_privacy: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tech_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainTechContactArgs']]] = None,
                 tech_privacy: Optional[pulumi.Input[bool]] = None,
                 transfer_lock: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Provides a resource to manage a domain that has been [registered](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/registrar-tld-list.html) and associated with the current AWS account.

        **This is an advanced resource** and has special caveats to be aware of when using it. Please read this document in its entirety before using this resource.

        The `route53domains.RegisteredDomain` resource behaves differently from normal resources in that if a domain has been registered, the provider does not _register_ this domain, but instead "adopts" it into management. A destroy does not delete the domain but does remove the resource from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.route53domains.RegisteredDomain("example",
            domain_name="example.com",
            name_servers=[
                aws.route53domains.RegisteredDomainNameServerArgs(
                    name="ns-195.awsdns-24.com",
                ),
                aws.route53domains.RegisteredDomainNameServerArgs(
                    name="ns-874.awsdns-45.net",
                ),
            ],
            tags={
                "Environment": "test",
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['RegisteredDomainAdminContactArgs']] admin_contact: Details about the domain administrative contact.
        :param pulumi.Input[bool] admin_privacy: Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] auto_renew: Whether the domain registration is set to renew automatically. Default: `true`.
        :param pulumi.Input[str] domain_name: The name of the registered domain.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RegisteredDomainNameServerArgs']]]] name_servers: The list of nameservers for the domain.
        :param pulumi.Input[pulumi.InputType['RegisteredDomainRegistrantContactArgs']] registrant_contact: Details about the domain registrant.
        :param pulumi.Input[bool] registrant_privacy: Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[pulumi.InputType['RegisteredDomainTechContactArgs']] tech_contact: Details about the domain technical contact.
        :param pulumi.Input[bool] tech_privacy: Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] transfer_lock: Whether the domain is locked for transfer. Default: `true`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RegisteredDomainArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage a domain that has been [registered](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/registrar-tld-list.html) and associated with the current AWS account.

        **This is an advanced resource** and has special caveats to be aware of when using it. Please read this document in its entirety before using this resource.

        The `route53domains.RegisteredDomain` resource behaves differently from normal resources in that if a domain has been registered, the provider does not _register_ this domain, but instead "adopts" it into management. A destroy does not delete the domain but does remove the resource from state.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example = aws.route53domains.RegisteredDomain("example",
            domain_name="example.com",
            name_servers=[
                aws.route53domains.RegisteredDomainNameServerArgs(
                    name="ns-195.awsdns-24.com",
                ),
                aws.route53domains.RegisteredDomainNameServerArgs(
                    name="ns-874.awsdns-45.net",
                ),
            ],
            tags={
                "Environment": "test",
            })
        ```

        :param str resource_name: The name of the resource.
        :param RegisteredDomainArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegisteredDomainArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 admin_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainAdminContactArgs']]] = None,
                 admin_privacy: Optional[pulumi.Input[bool]] = None,
                 auto_renew: Optional[pulumi.Input[bool]] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RegisteredDomainNameServerArgs']]]]] = None,
                 registrant_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainRegistrantContactArgs']]] = None,
                 registrant_privacy: Optional[pulumi.Input[bool]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tech_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainTechContactArgs']]] = None,
                 tech_privacy: Optional[pulumi.Input[bool]] = None,
                 transfer_lock: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegisteredDomainArgs.__new__(RegisteredDomainArgs)

            __props__.__dict__["admin_contact"] = admin_contact
            __props__.__dict__["admin_privacy"] = admin_privacy
            __props__.__dict__["auto_renew"] = auto_renew
            if domain_name is None and not opts.urn:
                raise TypeError("Missing required property 'domain_name'")
            __props__.__dict__["domain_name"] = domain_name
            __props__.__dict__["name_servers"] = name_servers
            __props__.__dict__["registrant_contact"] = registrant_contact
            __props__.__dict__["registrant_privacy"] = registrant_privacy
            __props__.__dict__["tags"] = tags
            __props__.__dict__["tech_contact"] = tech_contact
            __props__.__dict__["tech_privacy"] = tech_privacy
            __props__.__dict__["transfer_lock"] = transfer_lock
            __props__.__dict__["abuse_contact_email"] = None
            __props__.__dict__["abuse_contact_phone"] = None
            __props__.__dict__["creation_date"] = None
            __props__.__dict__["expiration_date"] = None
            __props__.__dict__["registrar_name"] = None
            __props__.__dict__["registrar_url"] = None
            __props__.__dict__["reseller"] = None
            __props__.__dict__["status_lists"] = None
            __props__.__dict__["tags_all"] = None
            __props__.__dict__["updated_date"] = None
            __props__.__dict__["whois_server"] = None
        super(RegisteredDomain, __self__).__init__(
            'aws:route53domains/registeredDomain:RegisteredDomain',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            abuse_contact_email: Optional[pulumi.Input[str]] = None,
            abuse_contact_phone: Optional[pulumi.Input[str]] = None,
            admin_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainAdminContactArgs']]] = None,
            admin_privacy: Optional[pulumi.Input[bool]] = None,
            auto_renew: Optional[pulumi.Input[bool]] = None,
            creation_date: Optional[pulumi.Input[str]] = None,
            domain_name: Optional[pulumi.Input[str]] = None,
            expiration_date: Optional[pulumi.Input[str]] = None,
            name_servers: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RegisteredDomainNameServerArgs']]]]] = None,
            registrant_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainRegistrantContactArgs']]] = None,
            registrant_privacy: Optional[pulumi.Input[bool]] = None,
            registrar_name: Optional[pulumi.Input[str]] = None,
            registrar_url: Optional[pulumi.Input[str]] = None,
            reseller: Optional[pulumi.Input[str]] = None,
            status_lists: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tech_contact: Optional[pulumi.Input[pulumi.InputType['RegisteredDomainTechContactArgs']]] = None,
            tech_privacy: Optional[pulumi.Input[bool]] = None,
            transfer_lock: Optional[pulumi.Input[bool]] = None,
            updated_date: Optional[pulumi.Input[str]] = None,
            whois_server: Optional[pulumi.Input[str]] = None) -> 'RegisteredDomain':
        """
        Get an existing RegisteredDomain resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] abuse_contact_email: Email address to contact to report incorrect contact information for a domain, to report that the domain is being used to send spam, to report that someone is cybersquatting on a domain name, or report some other type of abuse.
        :param pulumi.Input[str] abuse_contact_phone: Phone number for reporting abuse.
        :param pulumi.Input[pulumi.InputType['RegisteredDomainAdminContactArgs']] admin_contact: Details about the domain administrative contact.
        :param pulumi.Input[bool] admin_privacy: Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] auto_renew: Whether the domain registration is set to renew automatically. Default: `true`.
        :param pulumi.Input[str] creation_date: The date when the domain was created as found in the response to a WHOIS query.
        :param pulumi.Input[str] domain_name: The name of the registered domain.
        :param pulumi.Input[str] expiration_date: The date when the registration for the domain is set to expire.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RegisteredDomainNameServerArgs']]]] name_servers: The list of nameservers for the domain.
        :param pulumi.Input[pulumi.InputType['RegisteredDomainRegistrantContactArgs']] registrant_contact: Details about the domain registrant.
        :param pulumi.Input[bool] registrant_privacy: Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[str] registrar_name: Name of the registrar of the domain as identified in the registry.
        :param pulumi.Input[str] registrar_url: Web address of the registrar.
        :param pulumi.Input[str] reseller: Reseller of the domain.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] status_lists: List of [domain name status codes](https://www.icann.org/resources/pages/epp-status-codes-2014-06-16-en).
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        :param pulumi.Input[pulumi.InputType['RegisteredDomainTechContactArgs']] tech_contact: Details about the domain technical contact.
        :param pulumi.Input[bool] tech_privacy: Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        :param pulumi.Input[bool] transfer_lock: Whether the domain is locked for transfer. Default: `true`.
        :param pulumi.Input[str] updated_date: The last updated date of the domain as found in the response to a WHOIS query.
        :param pulumi.Input[str] whois_server: The fully qualified name of the WHOIS server that can answer the WHOIS query for the domain.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegisteredDomainState.__new__(_RegisteredDomainState)

        __props__.__dict__["abuse_contact_email"] = abuse_contact_email
        __props__.__dict__["abuse_contact_phone"] = abuse_contact_phone
        __props__.__dict__["admin_contact"] = admin_contact
        __props__.__dict__["admin_privacy"] = admin_privacy
        __props__.__dict__["auto_renew"] = auto_renew
        __props__.__dict__["creation_date"] = creation_date
        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["expiration_date"] = expiration_date
        __props__.__dict__["name_servers"] = name_servers
        __props__.__dict__["registrant_contact"] = registrant_contact
        __props__.__dict__["registrant_privacy"] = registrant_privacy
        __props__.__dict__["registrar_name"] = registrar_name
        __props__.__dict__["registrar_url"] = registrar_url
        __props__.__dict__["reseller"] = reseller
        __props__.__dict__["status_lists"] = status_lists
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_all"] = tags_all
        __props__.__dict__["tech_contact"] = tech_contact
        __props__.__dict__["tech_privacy"] = tech_privacy
        __props__.__dict__["transfer_lock"] = transfer_lock
        __props__.__dict__["updated_date"] = updated_date
        __props__.__dict__["whois_server"] = whois_server
        return RegisteredDomain(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="abuseContactEmail")
    def abuse_contact_email(self) -> pulumi.Output[str]:
        """
        Email address to contact to report incorrect contact information for a domain, to report that the domain is being used to send spam, to report that someone is cybersquatting on a domain name, or report some other type of abuse.
        """
        return pulumi.get(self, "abuse_contact_email")

    @property
    @pulumi.getter(name="abuseContactPhone")
    def abuse_contact_phone(self) -> pulumi.Output[str]:
        """
        Phone number for reporting abuse.
        """
        return pulumi.get(self, "abuse_contact_phone")

    @property
    @pulumi.getter(name="adminContact")
    def admin_contact(self) -> pulumi.Output['outputs.RegisteredDomainAdminContact']:
        """
        Details about the domain administrative contact.
        """
        return pulumi.get(self, "admin_contact")

    @property
    @pulumi.getter(name="adminPrivacy")
    def admin_privacy(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether domain administrative contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "admin_privacy")

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the domain registration is set to renew automatically. Default: `true`.
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> pulumi.Output[str]:
        """
        The date when the domain was created as found in the response to a WHOIS query.
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[str]:
        """
        The name of the registered domain.
        """
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> pulumi.Output[str]:
        """
        The date when the registration for the domain is set to expire.
        """
        return pulumi.get(self, "expiration_date")

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> pulumi.Output[Sequence['outputs.RegisteredDomainNameServer']]:
        """
        The list of nameservers for the domain.
        """
        return pulumi.get(self, "name_servers")

    @property
    @pulumi.getter(name="registrantContact")
    def registrant_contact(self) -> pulumi.Output['outputs.RegisteredDomainRegistrantContact']:
        """
        Details about the domain registrant.
        """
        return pulumi.get(self, "registrant_contact")

    @property
    @pulumi.getter(name="registrantPrivacy")
    def registrant_privacy(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether domain registrant contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "registrant_privacy")

    @property
    @pulumi.getter(name="registrarName")
    def registrar_name(self) -> pulumi.Output[str]:
        """
        Name of the registrar of the domain as identified in the registry.
        """
        return pulumi.get(self, "registrar_name")

    @property
    @pulumi.getter(name="registrarUrl")
    def registrar_url(self) -> pulumi.Output[str]:
        """
        Web address of the registrar.
        """
        return pulumi.get(self, "registrar_url")

    @property
    @pulumi.getter
    def reseller(self) -> pulumi.Output[str]:
        """
        Reseller of the domain.
        """
        return pulumi.get(self, "reseller")

    @property
    @pulumi.getter(name="statusLists")
    def status_lists(self) -> pulumi.Output[Sequence[str]]:
        """
        List of [domain name status codes](https://www.icann.org/resources/pages/epp-status-codes-2014-06-16-en).
        """
        return pulumi.get(self, "status_lists")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> pulumi.Output[Mapping[str, str]]:
        """
        A map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")

    @property
    @pulumi.getter(name="techContact")
    def tech_contact(self) -> pulumi.Output['outputs.RegisteredDomainTechContact']:
        """
        Details about the domain technical contact.
        """
        return pulumi.get(self, "tech_contact")

    @property
    @pulumi.getter(name="techPrivacy")
    def tech_privacy(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether domain technical contact information is concealed from WHOIS queries. Default: `true`.
        """
        return pulumi.get(self, "tech_privacy")

    @property
    @pulumi.getter(name="transferLock")
    def transfer_lock(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the domain is locked for transfer. Default: `true`.
        """
        return pulumi.get(self, "transfer_lock")

    @property
    @pulumi.getter(name="updatedDate")
    def updated_date(self) -> pulumi.Output[str]:
        """
        The last updated date of the domain as found in the response to a WHOIS query.
        """
        return pulumi.get(self, "updated_date")

    @property
    @pulumi.getter(name="whoisServer")
    def whois_server(self) -> pulumi.Output[str]:
        """
        The fully qualified name of the WHOIS server that can answer the WHOIS query for the domain.
        """
        return pulumi.get(self, "whois_server")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['VpnGatewayAttachmentArgs', 'VpnGatewayAttachment']

@pulumi.input_type
class VpnGatewayAttachmentArgs:
    def __init__(__self__, *,
                 vpc_id: pulumi.Input[str],
                 vpn_gateway_id: pulumi.Input[str]):
        """
        The set of arguments for constructing a VpnGatewayAttachment resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vpn_gateway_id: The ID of the Virtual Private Gateway.
        """
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> pulumi.Input[str]:
        """
        The ID of the Virtual Private Gateway.
        """
        return pulumi.get(self, "vpn_gateway_id")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpn_gateway_id", value)


@pulumi.input_type
class _VpnGatewayAttachmentState:
    def __init__(__self__, *,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VpnGatewayAttachment resources.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vpn_gateway_id: The ID of the Virtual Private Gateway.
        """
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpn_gateway_id is not None:
            pulumi.set(__self__, "vpn_gateway_id", vpn_gateway_id)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Virtual Private Gateway.
        """
        return pulumi.get(self, "vpn_gateway_id")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpn_gateway_id", value)


class VpnGatewayAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Virtual Private Gateway attachment resource, allowing for an existing
        hardware VPN gateway to be attached and/or detached from a VPC.

        > **Note:** The `ec2.VpnGateway`
        resource can also automatically attach the Virtual Private Gateway it creates
        to an existing VPC by setting the `vpc_id` attribute accordingly.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        network = aws.ec2.Vpc("network", cidr_block="10.0.0.0/16")
        vpn = aws.ec2.VpnGateway("vpn", tags={
            "Name": "example-vpn-gateway",
        })
        vpn_attachment = aws.ec2.VpnGatewayAttachment("vpnAttachment",
            vpc_id=network.id,
            vpn_gateway_id=vpn.id)
        ```

        See [Virtual Private Cloud](http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Introduction.html)
        and [Virtual Private Gateway](http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_VPN.html) user
        guides for more information.

        ## Import

        This resource does not support importing.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vpn_gateway_id: The ID of the Virtual Private Gateway.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpnGatewayAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Virtual Private Gateway attachment resource, allowing for an existing
        hardware VPN gateway to be attached and/or detached from a VPC.

        > **Note:** The `ec2.VpnGateway`
        resource can also automatically attach the Virtual Private Gateway it creates
        to an existing VPC by setting the `vpc_id` attribute accordingly.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        network = aws.ec2.Vpc("network", cidr_block="10.0.0.0/16")
        vpn = aws.ec2.VpnGateway("vpn", tags={
            "Name": "example-vpn-gateway",
        })
        vpn_attachment = aws.ec2.VpnGatewayAttachment("vpnAttachment",
            vpc_id=network.id,
            vpn_gateway_id=vpn.id)
        ```

        See [Virtual Private Cloud](http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_Introduction.html)
        and [Virtual Private Gateway](http://docs.aws.amazon.com/AmazonVPC/latest/UserGuide/VPC_VPN.html) user
        guides for more information.

        ## Import

        This resource does not support importing.

        :param str resource_name: The name of the resource.
        :param VpnGatewayAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpnGatewayAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 vpc_id: Optional[pulumi.Input[str]] = None,
                 vpn_gateway_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpnGatewayAttachmentArgs.__new__(VpnGatewayAttachmentArgs)

            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            if vpn_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpn_gateway_id'")
            __props__.__dict__["vpn_gateway_id"] = vpn_gateway_id
        super(VpnGatewayAttachment, __self__).__init__(
            'aws:ec2/vpnGatewayAttachment:VpnGatewayAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            vpc_id: Optional[pulumi.Input[str]] = None,
            vpn_gateway_id: Optional[pulumi.Input[str]] = None) -> 'VpnGatewayAttachment':
        """
        Get an existing VpnGatewayAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] vpc_id: The ID of the VPC.
        :param pulumi.Input[str] vpn_gateway_id: The ID of the Virtual Private Gateway.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpnGatewayAttachmentState.__new__(_VpnGatewayAttachmentState)

        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpn_gateway_id"] = vpn_gateway_id
        return VpnGatewayAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpnGatewayId")
    def vpn_gateway_id(self) -> pulumi.Output[str]:
        """
        The ID of the Virtual Private Gateway.
        """
        return pulumi.get(self, "vpn_gateway_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['DomainEntryArgs', 'DomainEntry']

@pulumi.input_type
class DomainEntryArgs:
    def __init__(__self__, *,
                 domain_name: pulumi.Input[str],
                 target: pulumi.Input[str],
                 type: pulumi.Input[str],
                 is_alias: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DomainEntry resource.
        :param pulumi.Input[str] domain_name: The name of the Lightsail domain in which to create the entry
        :param pulumi.Input[str] target: Target of the domain entry
        :param pulumi.Input[str] type: Type of record
        :param pulumi.Input[bool] is_alias: If the entry should be an alias Defaults to `false`
        :param pulumi.Input[str] name: Name of the entry record
        """
        pulumi.set(__self__, "domain_name", domain_name)
        pulumi.set(__self__, "target", target)
        pulumi.set(__self__, "type", type)
        if is_alias is not None:
            pulumi.set(__self__, "is_alias", is_alias)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Input[str]:
        """
        The name of the Lightsail domain in which to create the entry
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[str]:
        """
        Target of the domain entry
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[str]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Type of record
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="isAlias")
    def is_alias(self) -> Optional[pulumi.Input[bool]]:
        """
        If the entry should be an alias Defaults to `false`
        """
        return pulumi.get(self, "is_alias")

    @is_alias.setter
    def is_alias(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_alias", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the entry record
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DomainEntryState:
    def __init__(__self__, *,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 is_alias: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DomainEntry resources.
        :param pulumi.Input[str] domain_name: The name of the Lightsail domain in which to create the entry
        :param pulumi.Input[bool] is_alias: If the entry should be an alias Defaults to `false`
        :param pulumi.Input[str] name: Name of the entry record
        :param pulumi.Input[str] target: Target of the domain entry
        :param pulumi.Input[str] type: Type of record
        """
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if is_alias is not None:
            pulumi.set(__self__, "is_alias", is_alias)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Lightsail domain in which to create the entry
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain_name", value)

    @property
    @pulumi.getter(name="isAlias")
    def is_alias(self) -> Optional[pulumi.Input[bool]]:
        """
        If the entry should be an alias Defaults to `false`
        """
        return pulumi.get(self, "is_alias")

    @is_alias.setter
    def is_alias(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_alias", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the entry record
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[str]]:
        """
        Target of the domain entry
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of record
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


class DomainEntry(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 is_alias: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a domain entry resource

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        test_domain = aws.lightsail.Domain("testDomain", domain_name="mydomain.com")
        test_domain_entry = aws.lightsail.DomainEntry("testDomainEntry",
            domain_name=aws_lightsail_domain["domain_test"]["domain_name"],
            type="A",
            target="127.0.0.1")
        ```

        ## Import

        `aws_lightsail_domain_entry` can be imported by using the id attribute, e.g.,

        ```sh
         $ pulumi import aws:lightsail/domainEntry:DomainEntry example www_mydomain.com_A_127.0.0.1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain_name: The name of the Lightsail domain in which to create the entry
        :param pulumi.Input[bool] is_alias: If the entry should be an alias Defaults to `false`
        :param pulumi.Input[str] name: Name of the entry record
        :param pulumi.Input[str] target: Target of the domain entry
        :param pulumi.Input[str] type: Type of record
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DomainEntryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a domain entry resource

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        test_domain = aws.lightsail.Domain("testDomain", domain_name="mydomain.com")
        test_domain_entry = aws.lightsail.DomainEntry("testDomainEntry",
            domain_name=aws_lightsail_domain["domain_test"]["domain_name"],
            type="A",
            target="127.0.0.1")
        ```

        ## Import

        `aws_lightsail_domain_entry` can be imported by using the id attribute, e.g.,

        ```sh
         $ pulumi import aws:lightsail/domainEntry:DomainEntry example www_mydomain.com_A_127.0.0.1
        ```

        :param str resource_name: The name of the resource.
        :param DomainEntryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DomainEntryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain_name: Optional[pulumi.Input[str]] = None,
                 is_alias: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DomainEntryArgs.__new__(DomainEntryArgs)

            if domain_name is None and not opts.urn:
                raise TypeError("Missing required property 'domain_name'")
            __props__.__dict__["domain_name"] = domain_name
            __props__.__dict__["is_alias"] = is_alias
            __props__.__dict__["name"] = name
            if target is None and not opts.urn:
                raise TypeError("Missing required property 'target'")
            __props__.__dict__["target"] = target
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(DomainEntry, __self__).__init__(
            'aws:lightsail/domainEntry:DomainEntry',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain_name: Optional[pulumi.Input[str]] = None,
            is_alias: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            target: Optional[pulumi.Input[str]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'DomainEntry':
        """
        Get an existing DomainEntry resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain_name: The name of the Lightsail domain in which to create the entry
        :param pulumi.Input[bool] is_alias: If the entry should be an alias Defaults to `false`
        :param pulumi.Input[str] name: Name of the entry record
        :param pulumi.Input[str] target: Target of the domain entry
        :param pulumi.Input[str] type: Type of record
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DomainEntryState.__new__(_DomainEntryState)

        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["is_alias"] = is_alias
        __props__.__dict__["name"] = name
        __props__.__dict__["target"] = target
        __props__.__dict__["type"] = type
        return DomainEntry(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[str]:
        """
        The name of the Lightsail domain in which to create the entry
        """
        return pulumi.get(self, "domain_name")

    @property
    @pulumi.getter(name="isAlias")
    def is_alias(self) -> pulumi.Output[Optional[bool]]:
        """
        If the entry should be an alias Defaults to `false`
        """
        return pulumi.get(self, "is_alias")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the entry record
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[str]:
        """
        Target of the domain entry
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[str]:
        """
        Type of record
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['ApplicationArgs', 'Application']

@pulumi.input_type
class ApplicationArgs:
    def __init__(__self__, *,
                 resource_group_name: pulumi.Input[str],
                 auto_config_enabled: Optional[pulumi.Input[bool]] = None,
                 auto_create: Optional[pulumi.Input[bool]] = None,
                 cwe_monitor_enabled: Optional[pulumi.Input[bool]] = None,
                 grouping_type: Optional[pulumi.Input[str]] = None,
                 ops_center_enabled: Optional[pulumi.Input[bool]] = None,
                 ops_item_sns_topic_arn: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Application resource.
        :param pulumi.Input[str] resource_group_name: Name of the resource group.
        :param pulumi.Input[bool] auto_config_enabled: Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        :param pulumi.Input[bool] auto_create: Configures all of the resources in the resource group by applying the recommended configurations.
        :param pulumi.Input[bool] cwe_monitor_enabled: Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        :param pulumi.Input[str] grouping_type: Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        :param pulumi.Input[bool] ops_center_enabled: When set to `true`, creates opsItems for any problems detected on an application.
        :param pulumi.Input[str] ops_item_sns_topic_arn: SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if auto_config_enabled is not None:
            pulumi.set(__self__, "auto_config_enabled", auto_config_enabled)
        if auto_create is not None:
            pulumi.set(__self__, "auto_create", auto_create)
        if cwe_monitor_enabled is not None:
            pulumi.set(__self__, "cwe_monitor_enabled", cwe_monitor_enabled)
        if grouping_type is not None:
            pulumi.set(__self__, "grouping_type", grouping_type)
        if ops_center_enabled is not None:
            pulumi.set(__self__, "ops_center_enabled", ops_center_enabled)
        if ops_item_sns_topic_arn is not None:
            pulumi.set(__self__, "ops_item_sns_topic_arn", ops_item_sns_topic_arn)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        Name of the resource group.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="autoConfigEnabled")
    def auto_config_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        """
        return pulumi.get(self, "auto_config_enabled")

    @auto_config_enabled.setter
    def auto_config_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_config_enabled", value)

    @property
    @pulumi.getter(name="autoCreate")
    def auto_create(self) -> Optional[pulumi.Input[bool]]:
        """
        Configures all of the resources in the resource group by applying the recommended configurations.
        """
        return pulumi.get(self, "auto_create")

    @auto_create.setter
    def auto_create(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_create", value)

    @property
    @pulumi.getter(name="cweMonitorEnabled")
    def cwe_monitor_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        """
        return pulumi.get(self, "cwe_monitor_enabled")

    @cwe_monitor_enabled.setter
    def cwe_monitor_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cwe_monitor_enabled", value)

    @property
    @pulumi.getter(name="groupingType")
    def grouping_type(self) -> Optional[pulumi.Input[str]]:
        """
        Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        """
        return pulumi.get(self, "grouping_type")

    @grouping_type.setter
    def grouping_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "grouping_type", value)

    @property
    @pulumi.getter(name="opsCenterEnabled")
    def ops_center_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        When set to `true`, creates opsItems for any problems detected on an application.
        """
        return pulumi.get(self, "ops_center_enabled")

    @ops_center_enabled.setter
    def ops_center_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ops_center_enabled", value)

    @property
    @pulumi.getter(name="opsItemSnsTopicArn")
    def ops_item_sns_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        """
        return pulumi.get(self, "ops_item_sns_topic_arn")

    @ops_item_sns_topic_arn.setter
    def ops_item_sns_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ops_item_sns_topic_arn", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ApplicationState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 auto_config_enabled: Optional[pulumi.Input[bool]] = None,
                 auto_create: Optional[pulumi.Input[bool]] = None,
                 cwe_monitor_enabled: Optional[pulumi.Input[bool]] = None,
                 grouping_type: Optional[pulumi.Input[str]] = None,
                 ops_center_enabled: Optional[pulumi.Input[bool]] = None,
                 ops_item_sns_topic_arn: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering Application resources.
        :param pulumi.Input[str] arn: ARN of the Application.
        :param pulumi.Input[bool] auto_config_enabled: Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        :param pulumi.Input[bool] auto_create: Configures all of the resources in the resource group by applying the recommended configurations.
        :param pulumi.Input[bool] cwe_monitor_enabled: Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        :param pulumi.Input[str] grouping_type: Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        :param pulumi.Input[bool] ops_center_enabled: When set to `true`, creates opsItems for any problems detected on an application.
        :param pulumi.Input[str] ops_item_sns_topic_arn: SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        :param pulumi.Input[str] resource_group_name: Name of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if auto_config_enabled is not None:
            pulumi.set(__self__, "auto_config_enabled", auto_config_enabled)
        if auto_create is not None:
            pulumi.set(__self__, "auto_create", auto_create)
        if cwe_monitor_enabled is not None:
            pulumi.set(__self__, "cwe_monitor_enabled", cwe_monitor_enabled)
        if grouping_type is not None:
            pulumi.set(__self__, "grouping_type", grouping_type)
        if ops_center_enabled is not None:
            pulumi.set(__self__, "ops_center_enabled", ops_center_enabled)
        if ops_item_sns_topic_arn is not None:
            pulumi.set(__self__, "ops_item_sns_topic_arn", ops_item_sns_topic_arn)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tags_all is not None:
            pulumi.set(__self__, "tags_all", tags_all)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        ARN of the Application.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="autoConfigEnabled")
    def auto_config_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        """
        return pulumi.get(self, "auto_config_enabled")

    @auto_config_enabled.setter
    def auto_config_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_config_enabled", value)

    @property
    @pulumi.getter(name="autoCreate")
    def auto_create(self) -> Optional[pulumi.Input[bool]]:
        """
        Configures all of the resources in the resource group by applying the recommended configurations.
        """
        return pulumi.get(self, "auto_create")

    @auto_create.setter
    def auto_create(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "auto_create", value)

    @property
    @pulumi.getter(name="cweMonitorEnabled")
    def cwe_monitor_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        """
        return pulumi.get(self, "cwe_monitor_enabled")

    @cwe_monitor_enabled.setter
    def cwe_monitor_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cwe_monitor_enabled", value)

    @property
    @pulumi.getter(name="groupingType")
    def grouping_type(self) -> Optional[pulumi.Input[str]]:
        """
        Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        """
        return pulumi.get(self, "grouping_type")

    @grouping_type.setter
    def grouping_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "grouping_type", value)

    @property
    @pulumi.getter(name="opsCenterEnabled")
    def ops_center_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        When set to `true`, creates opsItems for any problems detected on an application.
        """
        return pulumi.get(self, "ops_center_enabled")

    @ops_center_enabled.setter
    def ops_center_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ops_center_enabled", value)

    @property
    @pulumi.getter(name="opsItemSnsTopicArn")
    def ops_item_sns_topic_arn(self) -> Optional[pulumi.Input[str]]:
        """
        SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        """
        return pulumi.get(self, "ops_item_sns_topic_arn")

    @ops_item_sns_topic_arn.setter
    def ops_item_sns_topic_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ops_item_sns_topic_arn", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the resource group.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")

    @tags_all.setter
    def tags_all(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags_all", value)


class Application(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_config_enabled: Optional[pulumi.Input[bool]] = None,
                 auto_create: Optional[pulumi.Input[bool]] = None,
                 cwe_monitor_enabled: Optional[pulumi.Input[bool]] = None,
                 grouping_type: Optional[pulumi.Input[str]] = None,
                 ops_center_enabled: Optional[pulumi.Input[bool]] = None,
                 ops_item_sns_topic_arn: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a ApplicationInsights Application resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_group = aws.resourcegroups.Group("exampleGroup", resource_query=aws.resourcegroups.GroupResourceQueryArgs(
            query=\"\"\"	{
        		"ResourceTypeFilters": [
        		  "AWS::EC2::Instance"
        		],
        		"TagFilters": [
        		  {
        			"Key": "Stage",
        			"Values": [
        			  "Test"
        			]
        		  }
        		]
        	  }
        \"\"\",
        ))
        example_application = aws.applicationinsights.Application("exampleApplication", resource_group_name=example_group.name)
        ```

        ## Import

        ApplicationInsights Applications can be imported using the `resource_group_name`, e.g.,

        ```sh
         $ pulumi import aws:applicationinsights/application:Application some some-application
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] auto_config_enabled: Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        :param pulumi.Input[bool] auto_create: Configures all of the resources in the resource group by applying the recommended configurations.
        :param pulumi.Input[bool] cwe_monitor_enabled: Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        :param pulumi.Input[str] grouping_type: Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        :param pulumi.Input[bool] ops_center_enabled: When set to `true`, creates opsItems for any problems detected on an application.
        :param pulumi.Input[str] ops_item_sns_topic_arn: SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        :param pulumi.Input[str] resource_group_name: Name of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ApplicationInsights Application resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_aws as aws

        example_group = aws.resourcegroups.Group("exampleGroup", resource_query=aws.resourcegroups.GroupResourceQueryArgs(
            query=\"\"\"	{
        		"ResourceTypeFilters": [
        		  "AWS::EC2::Instance"
        		],
        		"TagFilters": [
        		  {
        			"Key": "Stage",
        			"Values": [
        			  "Test"
        			]
        		  }
        		]
        	  }
        \"\"\",
        ))
        example_application = aws.applicationinsights.Application("exampleApplication", resource_group_name=example_group.name)
        ```

        ## Import

        ApplicationInsights Applications can be imported using the `resource_group_name`, e.g.,

        ```sh
         $ pulumi import aws:applicationinsights/application:Application some some-application
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auto_config_enabled: Optional[pulumi.Input[bool]] = None,
                 auto_create: Optional[pulumi.Input[bool]] = None,
                 cwe_monitor_enabled: Optional[pulumi.Input[bool]] = None,
                 grouping_type: Optional[pulumi.Input[str]] = None,
                 ops_center_enabled: Optional[pulumi.Input[bool]] = None,
                 ops_item_sns_topic_arn: Optional[pulumi.Input[str]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationArgs.__new__(ApplicationArgs)

            __props__.__dict__["auto_config_enabled"] = auto_config_enabled
            __props__.__dict__["auto_create"] = auto_create
            __props__.__dict__["cwe_monitor_enabled"] = cwe_monitor_enabled
            __props__.__dict__["grouping_type"] = grouping_type
            __props__.__dict__["ops_center_enabled"] = ops_center_enabled
            __props__.__dict__["ops_item_sns_topic_arn"] = ops_item_sns_topic_arn
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["arn"] = None
            __props__.__dict__["tags_all"] = None
        super(Application, __self__).__init__(
            'aws:applicationinsights/application:Application',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            auto_config_enabled: Optional[pulumi.Input[bool]] = None,
            auto_create: Optional[pulumi.Input[bool]] = None,
            cwe_monitor_enabled: Optional[pulumi.Input[bool]] = None,
            grouping_type: Optional[pulumi.Input[str]] = None,
            ops_center_enabled: Optional[pulumi.Input[bool]] = None,
            ops_item_sns_topic_arn: Optional[pulumi.Input[str]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            tags_all: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'Application':
        """
        Get an existing Application resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: ARN of the Application.
        :param pulumi.Input[bool] auto_config_enabled: Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        :param pulumi.Input[bool] auto_create: Configures all of the resources in the resource group by applying the recommended configurations.
        :param pulumi.Input[bool] cwe_monitor_enabled: Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        :param pulumi.Input[str] grouping_type: Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        :param pulumi.Input[bool] ops_center_enabled: When set to `true`, creates opsItems for any problems detected on an application.
        :param pulumi.Input[str] ops_item_sns_topic_arn: SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        :param pulumi.Input[str] resource_group_name: Name of the resource group.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags_all: Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationState.__new__(_ApplicationState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["auto_config_enabled"] = auto_config_enabled
        __props__.__dict__["auto_create"] = auto_create
        __props__.__dict__["cwe_monitor_enabled"] = cwe_monitor_enabled
        __props__.__dict__["grouping_type"] = grouping_type
        __props__.__dict__["ops_center_enabled"] = ops_center_enabled
        __props__.__dict__["ops_item_sns_topic_arn"] = ops_item_sns_topic_arn
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tags_all"] = tags_all
        return Application(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        ARN of the Application.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="autoConfigEnabled")
    def auto_config_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether Application Insights automatically configures unmonitored resources in the resource group.
        """
        return pulumi.get(self, "auto_config_enabled")

    @property
    @pulumi.getter(name="autoCreate")
    def auto_create(self) -> pulumi.Output[Optional[bool]]:
        """
        Configures all of the resources in the resource group by applying the recommended configurations.
        """
        return pulumi.get(self, "auto_create")

    @property
    @pulumi.getter(name="cweMonitorEnabled")
    def cwe_monitor_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others.
        """
        return pulumi.get(self, "cwe_monitor_enabled")

    @property
    @pulumi.getter(name="groupingType")
    def grouping_type(self) -> pulumi.Output[Optional[str]]:
        """
        Application Insights can create applications based on a resource group or on an account. To create an account-based application using all of the resources in the account, set this parameter to `ACCOUNT_BASED`.
        """
        return pulumi.get(self, "grouping_type")

    @property
    @pulumi.getter(name="opsCenterEnabled")
    def ops_center_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        When set to `true`, creates opsItems for any problems detected on an application.
        """
        return pulumi.get(self, "ops_center_enabled")

    @property
    @pulumi.getter(name="opsItemSnsTopicArn")
    def ops_item_sns_topic_arn(self) -> pulumi.Output[Optional[str]]:
        """
        SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem.
        """
        return pulumi.get(self, "ops_item_sns_topic_arn")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        Name of the resource group.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        Map of tags to assign to the resource. If configured with a provider `default_tags` configuration block present, tags with matching keys will overwrite those defined at the provider-level.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="tagsAll")
    def tags_all(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Map of tags assigned to the resource, including those inherited from the provider `default_tags` configuration block.
        """
        return pulumi.get(self, "tags_all")

